==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/WebTabPanelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabPanelDescription } from "./WebTabPanelDescription";
/**
 * @hidden
 */
export let WebTabPanelDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabPanelDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabPanelDescriptionMetadata.a == null) {
                WebTabPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabPanelDescriptionMetadata.c(WebTabPanelDescriptionMetadata.a);
            }
            if (a.g(WebTabPanelDescriptionMetadata.a)) {
                return;
            }
            a.s(WebTabPanelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabPanel");
        }
        static d(a) {
            WebTabPanelDescriptionMetadata.b(a);
            a.u("WebTabPanel", () => new WebTabPanelDescription());
            a.t("WebTabPanel", WebTabPanelDescriptionMetadata.a);
        }
    }
    WebTabPanelDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabPanelDescriptionMetadata, 'WebTabPanelDescriptionMetadata');
    WebTabPanelDescriptionMetadata.a = null;
    return WebTabPanelDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebTabPanelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabPanelDescription } from "./WebTabPanelDescription";
/**
 * @hidden
 */
export let WebTabPanelDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabPanelDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabPanelDescriptionMetadata.a == null) {
                WebTabPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabPanelDescriptionMetadata.c(WebTabPanelDescriptionMetadata.a);
            }
            if (a.j(WebTabPanelDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTabPanelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabPanel");
            a.item("__tagNameWC", "String:igc-tab-panel");
        }
        static d(a) {
            WebTabPanelDescriptionMetadata.b(a);
            a.aa("WebTabPanel", () => new WebTabPanelDescription());
            a.z("WebTabPanel", WebTabPanelDescriptionMetadata.a);
        }
    }
    WebTabPanelDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabPanelDescriptionMetadata, 'WebTabPanelDescriptionMetadata');
    WebTabPanelDescriptionMetadata.a = null;
    return WebTabPanelDescriptionMetadata;
})();
